@@ -1,5 +1,5 @@
 import json
-import os
+from pathlib import Path
 
 from fastapi import FastAPI
 
@@ -7,7 +7,7 @@ from main import app
 
 if __name__ == "__main__":
     print("Creating docs/openapi.json")
-    doc_dir = "./docs"
-    os.makedirs(doc_dir, exist_ok=True)
-    with open(f"{doc_dir}/openapi.json", "w") as f:
+    doc_dir = Path.cwd() / "docs"
+    doc_dir.mkdir(exist_ok=True)
+    with open(doc_dir / "openapi.json", "w") as f:
         json.dump(FastAPI.openapi(app), f)
