@@ -24,5 +24,7 @@ settings = Dynaconf(
         Validator("plugins.extractors.default", must_exist=True, is_type_of=bool),
         Validator("k8s.consumer_group_annotation", must_exist=True, is_type_of=str),
         Validator("graph_update_every", must_exist=True, is_type_of=int),
+        Validator("grafana.dashboards.topics", is_type_of=str),
+        Validator("grafana.dashboards.consumergroups", is_type_of=str),
     ],
 )
