@@ -1,13 +1,27 @@
 from typing import List
 
 import pytest
-from kubernetes.client import V1beta1CronJob, V1ObjectMeta
+from kubernetes.client import (
+    V1beta1CronJob,
+    V1beta1CronJobSpec,
+    V1beta1JobTemplateSpec,
+    V1Container,
+    V1EnvVar,
+    V1JobSpec,
+    V1ObjectMeta,
+    V1PodSpec,
+    V1PodTemplateSpec,
+)
 
 from streams_explorer.core.config import settings
+from streams_explorer.core.extractor.default.elasticsearch_sink import ElasticsearchSink
+from streams_explorer.core.extractor.default.generic import GenericSink, GenericSource
 from streams_explorer.core.extractor.extractor import Extractor
+from streams_explorer.core.k8s_app import K8sAppCronJob
 from streams_explorer.core.services.dataflow_graph import NodeTypesEnum
 from streams_explorer.defaultlinker import DefaultLinker
 from streams_explorer.extractors import extractor_container
+from streams_explorer.models.kafka_connector import KafkaConnectorTypesEnum
 from streams_explorer.models.node_information import (
     NodeInfoListItem,
     NodeInformation,
@@ -64,7 +78,21 @@ class TestStreamsExplorer:
 
     @pytest.fixture()
     def cron_jobs(self):
-        return [V1beta1CronJob(metadata=V1ObjectMeta(name="test"))]
+        env_prefix = "APP_"
+        envs = [
+            V1EnvVar(name="ENV_PREFIX", value=env_prefix),
+            V1EnvVar(name=env_prefix + "OUTPUT_TOPIC", value="output-topic"),
+        ]
+        container = V1Container(name="test-container", env=envs)
+        pod_spec = V1PodSpec(containers=[container])
+        pod_template_spec = V1PodTemplateSpec(spec=pod_spec)
+        job_spec = V1JobSpec(
+            template=pod_template_spec,
+            selector="",
+        )
+        job_template = V1beta1JobTemplateSpec(spec=job_spec)
+        spec = V1beta1CronJobSpec(job_template=job_template, schedule="* * * * *")
+        return [V1beta1CronJob(metadata=V1ObjectMeta(name="test-cronjob"), spec=spec)]
 
     @pytest.fixture()
     def fake_linker(self, mocker):
@@ -84,7 +112,11 @@ class TestStreamsExplorer:
         self, mocker, deployments, cron_jobs, monkeypatch, fake_linker
     ):
         explorer = StreamsExplorer(linking_service=fake_linker)
-        extractor_container.extractors = []
+        extractor_container.extractors = [
+            ElasticsearchSink(),
+            GenericSink(),
+            GenericSource(),
+        ]
         monkeypatch.setattr(settings.k8s, "consumer_group_annotation", "consumerGroup")
         mocker.patch.object(
             explorer, attribute="get_deployments", return_value=deployments
@@ -93,13 +125,26 @@ class TestStreamsExplorer:
         mocker.patch.object(explorer, attribute="get_cron_jobs", return_value=cron_jobs)
 
         def get_connectors():
-            return ["connector1", "connector2"]
+            return ["es-sink-connector", "generic-source-connector"]
 
         def get_connector_info(connector):
-            if connector == "connector1":
-                return ["output-topic1", "output-topic2"], {"test": "test_value"}
-            if connector == "connector2":
-                return ["output-topic3"], {"name": "test-sink"}
+            if connector == "es-sink-connector":
+                return {
+                    "config": {
+                        "connector.class": "io.confluent.connect.elasticsearch.ElasticsearchSinkConnector",
+                        "test": "test_value",
+                        "topics": "output-topic1,output-topic2",
+                    },
+                    "type": KafkaConnectorTypesEnum.SINK,
+                }
+            if connector == "generic-source-connector":
+                return {
+                    "config": {
+                        "connector.class": "GenericSourceConnector",
+                        "name": "generic-source",
+                    },
+                    "type": KafkaConnectorTypesEnum.SOURCE,
+                }
 
         mocker.patch(
             "streams_explorer.core.services.kafkaconnect.KafkaConnect.get_connectors",
@@ -109,6 +154,10 @@ class TestStreamsExplorer:
             "streams_explorer.core.services.kafkaconnect.KafkaConnect.get_connector_info",
             get_connector_info,
         )
+        mocker.patch(
+            "streams_explorer.core.services.kafkaconnect.KafkaConnect.sanitize_connector_config",
+            lambda config: config,
+        )
 
         mocker.patch(
             "streams_explorer.core.services.schemaregistry.SchemaRegistry.get_topic_value_schema_versions",
@@ -131,6 +180,7 @@ class TestStreamsExplorer:
         assert streams_explorer.get_pipeline_names() == [
             "streaming-app1",
             "pipeline2",
+            "generic-source-connector",
         ]
 
     def test_get_node_information(self, streams_explorer, monkeypatch):
@@ -146,8 +196,10 @@ class TestStreamsExplorer:
             [{"name": "Test Label", "key": "metadata.labels.test_label"}],
         )
 
-        assert streams_explorer.get_node_information("connector1") == NodeInformation(
-            node_id="connector1",
+        assert streams_explorer.get_node_information(
+            "es-sink-connector"
+        ) == NodeInformation(
+            node_id="es-sink-connector",
             node_type=NodeTypesEnum.CONNECTOR,
             info=[
                 NodeInfoListItem(
@@ -183,14 +235,16 @@ class TestStreamsExplorer:
 
             def on_cron_job_parsing(self, cron_job: V1beta1CronJob):
                 self.cron_job = cron_job
+                return K8sAppCronJob(cron_job)
 
         extractor = MockCronjobExtractor()
         extractor_container.extractors = [extractor]
         streams_explorer.update()
-        assert extractor.cron_job.metadata.name == "test"
+        assert extractor.cron_job.metadata.name == "test-cronjob"
+        assert "test-cronjob" in streams_explorer.applications
         extractor_container.extractors = []
 
-    def test_get_link(self, monkeypatch, streams_explorer):
+    def test_get_link(self, streams_explorer):
         streams_explorer.update()
         assert type(streams_explorer.get_link("input-topic1", "grafana")) == str
         assert type(streams_explorer.get_link("input-topic1", "akhq")) == str
@@ -198,6 +252,6 @@ class TestStreamsExplorer:
             "streaming-app2", "grafana"
         )
         assert type(streams_explorer.get_link("streaming-app2", "kibanalogs")) == str
-        assert "consumergroups=connect-test-sink" in streams_explorer.get_link(
-            "connector2", "grafana"
+        assert "consumergroups=connect-generic-source" in streams_explorer.get_link(
+            "generic-source-connector", "grafana"
         )
